<template>
  <div class="svg-container" v-html="svgContent"/>
</template>

<script setup>
import {onMounted, ref, watch} from 'vue';

// Props
const props = defineProps({
  name: {
    type: String
  },
  size: {
    type: String,
    default: '20'
  },
  color: {
    type: String,
    default: 'black'
  },
  textColor: {
    type: String,
    default: 'black'
  },
  type: {
    type: String,
    default: 'filled'
  },
});

// State
const svgContent = ref('');

// Methods
const fetchSvg = async () => {
  const svgFilePath = '/icons/' + props.type + '/' + props.name + '.svg';
  try {
    const response = await fetch(svgFilePath);
    if (!response.ok) {
      throw new Error(`Failed to load SVG: ${svgFilePath}`);
    }
    const svgText = await response.text();
    svgContent.value = svgText.replaceAll(/fill=".*?"/g, `fill="${props.color}"`)
        .replaceAll(/width=".*?"/g, `width="${props.size}"`)
        .replaceAll(/height=".*?"/g, `height="${props.size}"`);
  } catch (error) {
    console.error(error);
  }
};

// Watch for prop changes
watch([() => props.name, () => props.color,() => props.size,() => props.type], fetchSvg);

// Initial load
onMounted(fetchSvg);
</script>

<style scoped>
.svg-container {
  display: inline-block;
}
</style>
